Jenkins Job Builder
===================

"Jenkins Job Builder" is the source for obtaining information from jenkins job definitions repositories.
It's supported only with Jenkins CI/CD system.

Usage
^^^^^

To following is a configuration sample of how to configure the 'Jenkins Job Builder' source

.. include:: ../config_samples/jjb_configuration.rst

Plugin Support
^^^^^^^^^^^^^^

The 'Jenkins Job Builder' source is supported by the following built-in plugins:

  * OpenStack
